require 'spec_helper'

describe SidekiqStrategies::BeanstalkdHandler do

  before(:each) do
    jobs          = create_double_beaneater_jobs({1=>create_double_beaneater_job, 2=>nil})
    tube_pronet   = create_double_beaneater_tube(:name=>'pronet')
    tubes         = {'pronet' => tube_pronet}
    pool          = create_double_beaneater_pool({:jobs=>jobs, :tubes=>tubes})
    @bns_handler  = SidekiqStrategies::BeanstalkdHandler.new( pool )
  end

  describe '#new' do

    it 'return an BeanstalkdHandler object' do
      expect( @bns_handler ).to be_a SidekiqStrategies::BeanstalkdHandler   
    end

  end

  describe 'public instance methods' do

    it '#obtain_tube should return a tube with name pronet' do
      expect( @bns_handler.obtain_tube('pronet') ).to_not be(nil)
      expect( @bns_handler.obtain_tube('pronet').name ).to eq('pronet')
    end

    it '#find_job with param 1 should return an specific job' do
      expect( @bns_handler.find_job(1) ).to_not be(nil)
    end

    it '#find_job with param 2 should return null' do
      expect( @bns_handler.find_job(2) ).to be(nil)
    end    

  end

  describe 'private instance methods' do

    it '#conn should return a Beaneater::Pool object' do
      expect( @bns_handler.send(:conn) ).to be_an(create_double_beaneater_pool.class)
    end

    it '#host should be a valid host name' do
      expect( @bns_handler.send(:host) ).to eql('localhost:11300')
    end

  end

end