require 'spec_helper'

describe SidekiqStrategies::Helper do

  before(:each) do
    @acc_handler = SidekiqStrategies::AccountHandler.new(120, 250, :query, 0, Spool::Publisher)
    @helper = SidekiqStrategies::Helper.new(@acc_handler, Rails.application.routes.url_helpers)
  end

  describe '#new' do

    it 'return an instance of Helper object' do
      expect( @helper ).to be_an(SidekiqStrategies::Helper)
    end

  end

  describe 'instance methods' do

    it '#reply_tube_name should return a valid tube name' do
      expect( @helper.reply_tube_name ).to eql("gt-120")
    end

    it '#request_tube_name should return a valid tube name' do
      expect( @helper.request_tube_name ).to eql("pronet")
    end

    it '#queue_message should return a valid message' do
      queue_message = {
        :account => 120,
        :account_url => "http://api.bluekite.com/v1/services/gt/claro-postpay/accounts/120",
        :action => :query,
        :fields => {:reference=>"", :end_user_id=>"", :priority=>"normal", :code=>"", :end_user_ip_address=>"192.168.0.1", :monitor_as_url=>"http://10.33.33.22:3000/v1/services/gt/claro-postpay/accounts/1", :account_number=>"55748576", :total_cents=>""},
        :number => "55748576",
        :provider => "claro_postpay",
        :reply_tube => "gt-120",
        :request_tube => "pronet",
        :retry_count => 0,
        :service => "claro-postpay"
      }
      expect( @helper.queue_message ).to eql(queue_message)
    end

    describe '#try_again?' do
      it 'should return false if transaction.retry_count is greater than 2' do
        @helper.acc_handler.transaction.retry_count = 5
        expect( @helper.try_again?(nil) ).to eql(false)
      end

      it 'should return true if it is an a retryable exception' do
        expect( @helper.try_again?({:retry_action => true}) ).to eql(true)
      end

      it 'should return false if it isn\'t an a retryable exception' do
        expect( @helper.try_again?({:retry_action => false}) ).to eql(false)
      end
    end

  end

end